"""Subpackage."""

from typing import TYPE_CHECKING as __tc


if __tc:
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3205 import (
        AbstractAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3206 import (
        AbstractShaftCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3207 import (
        AbstractShaftOrHousingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3208 import (
        AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3209 import (
        AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3210 import (
        AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3211 import (
        AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3212 import (
        AssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3213 import (
        BearingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3214 import (
        BeltConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3215 import (
        BeltDriveCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3216 import (
        BevelDifferentialGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3217 import (
        BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3218 import (
        BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3219 import (
        BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3220 import (
        BevelDifferentialSunGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3221 import (
        BevelGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3222 import (
        BevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3223 import (
        BevelGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3224 import (
        BoltCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3225 import (
        BoltedJointCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3226 import (
        ClutchCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3227 import (
        ClutchConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3228 import (
        ClutchHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3229 import (
        CoaxialConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3230 import (
        ComponentCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3231 import (
        ConceptCouplingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3232 import (
        ConceptCouplingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3233 import (
        ConceptCouplingHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3234 import (
        ConceptGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3235 import (
        ConceptGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3236 import (
        ConceptGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3237 import (
        ConicalGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3238 import (
        ConicalGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3239 import (
        ConicalGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3240 import (
        ConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3241 import (
        ConnectorCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3242 import (
        CouplingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3243 import (
        CouplingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3244 import (
        CouplingHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3245 import (
        CVTBeltConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3246 import (
        CVTCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3247 import (
        CVTPulleyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3248 import (
        CycloidalAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3249 import (
        CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3250 import (
        CycloidalDiscCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3251 import (
        CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3252 import (
        CylindricalGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3253 import (
        CylindricalGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3254 import (
        CylindricalGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3255 import (
        CylindricalPlanetGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3256 import (
        DatumCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3257 import (
        ExternalCADModelCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3258 import (
        FaceGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3259 import (
        FaceGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3260 import (
        FaceGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3261 import (
        FEPartCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3262 import (
        FlexiblePinAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3263 import (
        GearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3264 import (
        GearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3265 import (
        GearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3266 import (
        GuideDxfModelCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3267 import (
        HypoidGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3268 import (
        HypoidGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3269 import (
        HypoidGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3270 import (
        InterMountableComponentConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3271 import (
        KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3272 import (
        KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3273 import (
        KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3274 import (
        KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3275 import (
        KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3276 import (
        KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3277 import (
        KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3278 import (
        KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3279 import (
        KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3280 import (
        MassDiscCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3281 import (
        MeasurementComponentCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3282 import (
        MicrophoneArrayCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3283 import (
        MicrophoneCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3284 import (
        MountableComponentCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3285 import (
        OilSealCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3286 import (
        PartCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3287 import (
        PartToPartShearCouplingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3288 import (
        PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3289 import (
        PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3290 import (
        PlanetaryConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3291 import (
        PlanetaryGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3292 import (
        PlanetCarrierCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3293 import (
        PointLoadCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3294 import (
        PowerLoadCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3295 import (
        PulleyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3296 import (
        RingPinsCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3297 import (
        RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3298 import (
        RollingRingAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3299 import (
        RollingRingCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3300 import (
        RollingRingConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3301 import (
        RootAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3302 import (
        ShaftCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3303 import (
        ShaftHubConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3304 import (
        ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3305 import (
        SpecialisedAssemblyCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3306 import (
        SpiralBevelGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3307 import (
        SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3308 import (
        SpiralBevelGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3309 import (
        SpringDamperCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3310 import (
        SpringDamperConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3311 import (
        SpringDamperHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3312 import (
        StraightBevelDiffGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3313 import (
        StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3314 import (
        StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3315 import (
        StraightBevelGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3316 import (
        StraightBevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3317 import (
        StraightBevelGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3318 import (
        StraightBevelPlanetGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3319 import (
        StraightBevelSunGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3320 import (
        SynchroniserCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3321 import (
        SynchroniserHalfCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3322 import (
        SynchroniserPartCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3323 import (
        SynchroniserSleeveCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3324 import (
        TorqueConverterCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3325 import (
        TorqueConverterConnectionCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3326 import (
        TorqueConverterPumpCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3327 import (
        TorqueConverterTurbineCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3328 import (
        UnbalancedMassCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3329 import (
        VirtualComponentCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3330 import (
        WormGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3331 import (
        WormGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3332 import (
        WormGearSetCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3333 import (
        ZerolBevelGearCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3334 import (
        ZerolBevelGearMeshCompoundSteadyStateSynchronousResponse,
    )
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3335 import (
        ZerolBevelGearSetCompoundSteadyStateSynchronousResponse,
    )
else:
    import sys as __sys

    from lazy_imports import LazyImporter as __LazyImporter

    __import_structure = {
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3205": [
            "AbstractAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3206": [
            "AbstractShaftCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3207": [
            "AbstractShaftOrHousingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3208": [
            "AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3209": [
            "AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3210": [
            "AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3211": [
            "AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3212": [
            "AssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3213": [
            "BearingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3214": [
            "BeltConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3215": [
            "BeltDriveCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3216": [
            "BevelDifferentialGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3217": [
            "BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3218": [
            "BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3219": [
            "BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3220": [
            "BevelDifferentialSunGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3221": [
            "BevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3222": [
            "BevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3223": [
            "BevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3224": [
            "BoltCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3225": [
            "BoltedJointCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3226": [
            "ClutchCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3227": [
            "ClutchConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3228": [
            "ClutchHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3229": [
            "CoaxialConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3230": [
            "ComponentCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3231": [
            "ConceptCouplingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3232": [
            "ConceptCouplingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3233": [
            "ConceptCouplingHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3234": [
            "ConceptGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3235": [
            "ConceptGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3236": [
            "ConceptGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3237": [
            "ConicalGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3238": [
            "ConicalGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3239": [
            "ConicalGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3240": [
            "ConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3241": [
            "ConnectorCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3242": [
            "CouplingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3243": [
            "CouplingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3244": [
            "CouplingHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3245": [
            "CVTBeltConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3246": [
            "CVTCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3247": [
            "CVTPulleyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3248": [
            "CycloidalAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3249": [
            "CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3250": [
            "CycloidalDiscCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3251": [
            "CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3252": [
            "CylindricalGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3253": [
            "CylindricalGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3254": [
            "CylindricalGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3255": [
            "CylindricalPlanetGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3256": [
            "DatumCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3257": [
            "ExternalCADModelCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3258": [
            "FaceGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3259": [
            "FaceGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3260": [
            "FaceGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3261": [
            "FEPartCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3262": [
            "FlexiblePinAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3263": [
            "GearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3264": [
            "GearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3265": [
            "GearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3266": [
            "GuideDxfModelCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3267": [
            "HypoidGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3268": [
            "HypoidGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3269": [
            "HypoidGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3270": [
            "InterMountableComponentConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3271": [
            "KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3272": [
            "KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3273": [
            "KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3274": [
            "KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3275": [
            "KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3276": [
            "KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3277": [
            "KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3278": [
            "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3279": [
            "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3280": [
            "MassDiscCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3281": [
            "MeasurementComponentCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3282": [
            "MicrophoneArrayCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3283": [
            "MicrophoneCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3284": [
            "MountableComponentCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3285": [
            "OilSealCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3286": [
            "PartCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3287": [
            "PartToPartShearCouplingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3288": [
            "PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3289": [
            "PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3290": [
            "PlanetaryConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3291": [
            "PlanetaryGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3292": [
            "PlanetCarrierCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3293": [
            "PointLoadCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3294": [
            "PowerLoadCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3295": [
            "PulleyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3296": [
            "RingPinsCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3297": [
            "RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3298": [
            "RollingRingAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3299": [
            "RollingRingCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3300": [
            "RollingRingConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3301": [
            "RootAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3302": [
            "ShaftCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3303": [
            "ShaftHubConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3304": [
            "ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3305": [
            "SpecialisedAssemblyCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3306": [
            "SpiralBevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3307": [
            "SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3308": [
            "SpiralBevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3309": [
            "SpringDamperCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3310": [
            "SpringDamperConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3311": [
            "SpringDamperHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3312": [
            "StraightBevelDiffGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3313": [
            "StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3314": [
            "StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3315": [
            "StraightBevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3316": [
            "StraightBevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3317": [
            "StraightBevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3318": [
            "StraightBevelPlanetGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3319": [
            "StraightBevelSunGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3320": [
            "SynchroniserCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3321": [
            "SynchroniserHalfCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3322": [
            "SynchroniserPartCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3323": [
            "SynchroniserSleeveCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3324": [
            "TorqueConverterCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3325": [
            "TorqueConverterConnectionCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3326": [
            "TorqueConverterPumpCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3327": [
            "TorqueConverterTurbineCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3328": [
            "UnbalancedMassCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3329": [
            "VirtualComponentCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3330": [
            "WormGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3331": [
            "WormGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3332": [
            "WormGearSetCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3333": [
            "ZerolBevelGearCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3334": [
            "ZerolBevelGearMeshCompoundSteadyStateSynchronousResponse"
        ],
        "_private.system_model.analyses_and_results.steady_state_synchronous_responses.compound._3335": [
            "ZerolBevelGearSetCompoundSteadyStateSynchronousResponse"
        ],
    }

    __sys.modules[__name__] = __LazyImporter(
        "mastapy",
        globals()["__file__"],
        __import_structure,
    )

__all__ = (
    "AbstractAssemblyCompoundSteadyStateSynchronousResponse",
    "AbstractShaftCompoundSteadyStateSynchronousResponse",
    "AbstractShaftOrHousingCompoundSteadyStateSynchronousResponse",
    "AbstractShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse",
    "AGMAGleasonConicalGearCompoundSteadyStateSynchronousResponse",
    "AGMAGleasonConicalGearMeshCompoundSteadyStateSynchronousResponse",
    "AGMAGleasonConicalGearSetCompoundSteadyStateSynchronousResponse",
    "AssemblyCompoundSteadyStateSynchronousResponse",
    "BearingCompoundSteadyStateSynchronousResponse",
    "BeltConnectionCompoundSteadyStateSynchronousResponse",
    "BeltDriveCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialGearCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialGearMeshCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialGearSetCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialPlanetGearCompoundSteadyStateSynchronousResponse",
    "BevelDifferentialSunGearCompoundSteadyStateSynchronousResponse",
    "BevelGearCompoundSteadyStateSynchronousResponse",
    "BevelGearMeshCompoundSteadyStateSynchronousResponse",
    "BevelGearSetCompoundSteadyStateSynchronousResponse",
    "BoltCompoundSteadyStateSynchronousResponse",
    "BoltedJointCompoundSteadyStateSynchronousResponse",
    "ClutchCompoundSteadyStateSynchronousResponse",
    "ClutchConnectionCompoundSteadyStateSynchronousResponse",
    "ClutchHalfCompoundSteadyStateSynchronousResponse",
    "CoaxialConnectionCompoundSteadyStateSynchronousResponse",
    "ComponentCompoundSteadyStateSynchronousResponse",
    "ConceptCouplingCompoundSteadyStateSynchronousResponse",
    "ConceptCouplingConnectionCompoundSteadyStateSynchronousResponse",
    "ConceptCouplingHalfCompoundSteadyStateSynchronousResponse",
    "ConceptGearCompoundSteadyStateSynchronousResponse",
    "ConceptGearMeshCompoundSteadyStateSynchronousResponse",
    "ConceptGearSetCompoundSteadyStateSynchronousResponse",
    "ConicalGearCompoundSteadyStateSynchronousResponse",
    "ConicalGearMeshCompoundSteadyStateSynchronousResponse",
    "ConicalGearSetCompoundSteadyStateSynchronousResponse",
    "ConnectionCompoundSteadyStateSynchronousResponse",
    "ConnectorCompoundSteadyStateSynchronousResponse",
    "CouplingCompoundSteadyStateSynchronousResponse",
    "CouplingConnectionCompoundSteadyStateSynchronousResponse",
    "CouplingHalfCompoundSteadyStateSynchronousResponse",
    "CVTBeltConnectionCompoundSteadyStateSynchronousResponse",
    "CVTCompoundSteadyStateSynchronousResponse",
    "CVTPulleyCompoundSteadyStateSynchronousResponse",
    "CycloidalAssemblyCompoundSteadyStateSynchronousResponse",
    "CycloidalDiscCentralBearingConnectionCompoundSteadyStateSynchronousResponse",
    "CycloidalDiscCompoundSteadyStateSynchronousResponse",
    "CycloidalDiscPlanetaryBearingConnectionCompoundSteadyStateSynchronousResponse",
    "CylindricalGearCompoundSteadyStateSynchronousResponse",
    "CylindricalGearMeshCompoundSteadyStateSynchronousResponse",
    "CylindricalGearSetCompoundSteadyStateSynchronousResponse",
    "CylindricalPlanetGearCompoundSteadyStateSynchronousResponse",
    "DatumCompoundSteadyStateSynchronousResponse",
    "ExternalCADModelCompoundSteadyStateSynchronousResponse",
    "FaceGearCompoundSteadyStateSynchronousResponse",
    "FaceGearMeshCompoundSteadyStateSynchronousResponse",
    "FaceGearSetCompoundSteadyStateSynchronousResponse",
    "FEPartCompoundSteadyStateSynchronousResponse",
    "FlexiblePinAssemblyCompoundSteadyStateSynchronousResponse",
    "GearCompoundSteadyStateSynchronousResponse",
    "GearMeshCompoundSteadyStateSynchronousResponse",
    "GearSetCompoundSteadyStateSynchronousResponse",
    "GuideDxfModelCompoundSteadyStateSynchronousResponse",
    "HypoidGearCompoundSteadyStateSynchronousResponse",
    "HypoidGearMeshCompoundSteadyStateSynchronousResponse",
    "HypoidGearSetCompoundSteadyStateSynchronousResponse",
    "InterMountableComponentConnectionCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidConicalGearCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidConicalGearMeshCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidConicalGearSetCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidHypoidGearCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidHypoidGearMeshCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidHypoidGearSetCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidSpiralBevelGearCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidSpiralBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "KlingelnbergCycloPalloidSpiralBevelGearSetCompoundSteadyStateSynchronousResponse",
    "MassDiscCompoundSteadyStateSynchronousResponse",
    "MeasurementComponentCompoundSteadyStateSynchronousResponse",
    "MicrophoneArrayCompoundSteadyStateSynchronousResponse",
    "MicrophoneCompoundSteadyStateSynchronousResponse",
    "MountableComponentCompoundSteadyStateSynchronousResponse",
    "OilSealCompoundSteadyStateSynchronousResponse",
    "PartCompoundSteadyStateSynchronousResponse",
    "PartToPartShearCouplingCompoundSteadyStateSynchronousResponse",
    "PartToPartShearCouplingConnectionCompoundSteadyStateSynchronousResponse",
    "PartToPartShearCouplingHalfCompoundSteadyStateSynchronousResponse",
    "PlanetaryConnectionCompoundSteadyStateSynchronousResponse",
    "PlanetaryGearSetCompoundSteadyStateSynchronousResponse",
    "PlanetCarrierCompoundSteadyStateSynchronousResponse",
    "PointLoadCompoundSteadyStateSynchronousResponse",
    "PowerLoadCompoundSteadyStateSynchronousResponse",
    "PulleyCompoundSteadyStateSynchronousResponse",
    "RingPinsCompoundSteadyStateSynchronousResponse",
    "RingPinsToDiscConnectionCompoundSteadyStateSynchronousResponse",
    "RollingRingAssemblyCompoundSteadyStateSynchronousResponse",
    "RollingRingCompoundSteadyStateSynchronousResponse",
    "RollingRingConnectionCompoundSteadyStateSynchronousResponse",
    "RootAssemblyCompoundSteadyStateSynchronousResponse",
    "ShaftCompoundSteadyStateSynchronousResponse",
    "ShaftHubConnectionCompoundSteadyStateSynchronousResponse",
    "ShaftToMountableComponentConnectionCompoundSteadyStateSynchronousResponse",
    "SpecialisedAssemblyCompoundSteadyStateSynchronousResponse",
    "SpiralBevelGearCompoundSteadyStateSynchronousResponse",
    "SpiralBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "SpiralBevelGearSetCompoundSteadyStateSynchronousResponse",
    "SpringDamperCompoundSteadyStateSynchronousResponse",
    "SpringDamperConnectionCompoundSteadyStateSynchronousResponse",
    "SpringDamperHalfCompoundSteadyStateSynchronousResponse",
    "StraightBevelDiffGearCompoundSteadyStateSynchronousResponse",
    "StraightBevelDiffGearMeshCompoundSteadyStateSynchronousResponse",
    "StraightBevelDiffGearSetCompoundSteadyStateSynchronousResponse",
    "StraightBevelGearCompoundSteadyStateSynchronousResponse",
    "StraightBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "StraightBevelGearSetCompoundSteadyStateSynchronousResponse",
    "StraightBevelPlanetGearCompoundSteadyStateSynchronousResponse",
    "StraightBevelSunGearCompoundSteadyStateSynchronousResponse",
    "SynchroniserCompoundSteadyStateSynchronousResponse",
    "SynchroniserHalfCompoundSteadyStateSynchronousResponse",
    "SynchroniserPartCompoundSteadyStateSynchronousResponse",
    "SynchroniserSleeveCompoundSteadyStateSynchronousResponse",
    "TorqueConverterCompoundSteadyStateSynchronousResponse",
    "TorqueConverterConnectionCompoundSteadyStateSynchronousResponse",
    "TorqueConverterPumpCompoundSteadyStateSynchronousResponse",
    "TorqueConverterTurbineCompoundSteadyStateSynchronousResponse",
    "UnbalancedMassCompoundSteadyStateSynchronousResponse",
    "VirtualComponentCompoundSteadyStateSynchronousResponse",
    "WormGearCompoundSteadyStateSynchronousResponse",
    "WormGearMeshCompoundSteadyStateSynchronousResponse",
    "WormGearSetCompoundSteadyStateSynchronousResponse",
    "ZerolBevelGearCompoundSteadyStateSynchronousResponse",
    "ZerolBevelGearMeshCompoundSteadyStateSynchronousResponse",
    "ZerolBevelGearSetCompoundSteadyStateSynchronousResponse",
)



"""GenericMatrix"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar, Generic, TypeVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal import conversion, utility
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_GENERIC_MATRIX = python_net_import("SMT.MastaAPI.MathUtility", "GenericMatrix")

if TYPE_CHECKING:
    from typing import Any, Type, List

    from mastapy._private.math_utility import (
        _1540,
        _1542,
        _1543,
        _1544,
        _1555,
        _1570,
        _1571,
        _1572,
        _1577,
        _1582,
    )

    Self = TypeVar("Self", bound="GenericMatrix")
    CastSelf = TypeVar("CastSelf", bound="GenericMatrix._Cast_GenericMatrix")

TElement = TypeVar("TElement", bound="object")
TMatrix = TypeVar("TMatrix", bound="GenericMatrix")

__docformat__ = "restructuredtext en"
__all__ = ("GenericMatrix",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_GenericMatrix:
    """Special nested class for casting GenericMatrix to subclasses."""

    __parent__: "GenericMatrix"

    @property
    def complex_matrix(self: "CastSelf") -> "_1540.ComplexMatrix":
        from mastapy._private.math_utility import _1540

        return self.__parent__._cast(_1540.ComplexMatrix)

    @property
    def complex_vector(self: "CastSelf") -> "_1542.ComplexVector":
        from mastapy._private.math_utility import _1542

        return self.__parent__._cast(_1542.ComplexVector)

    @property
    def complex_vector_3d(self: "CastSelf") -> "_1543.ComplexVector3D":
        from mastapy._private.math_utility import _1543

        return self.__parent__._cast(_1543.ComplexVector3D)

    @property
    def complex_vector_6d(self: "CastSelf") -> "_1544.ComplexVector6D":
        from mastapy._private.math_utility import _1544

        return self.__parent__._cast(_1544.ComplexVector6D)

    @property
    def euler_parameters(self: "CastSelf") -> "_1555.EulerParameters":
        from mastapy._private.math_utility import _1555

        return self.__parent__._cast(_1555.EulerParameters)

    @property
    def quaternion(self: "CastSelf") -> "_1570.Quaternion":
        from mastapy._private.math_utility import _1570

        return self.__parent__._cast(_1570.Quaternion)

    @property
    def real_matrix(self: "CastSelf") -> "_1571.RealMatrix":
        from mastapy._private.math_utility import _1571

        return self.__parent__._cast(_1571.RealMatrix)

    @property
    def real_vector(self: "CastSelf") -> "_1572.RealVector":
        from mastapy._private.math_utility import _1572

        return self.__parent__._cast(_1572.RealVector)

    @property
    def square_matrix(self: "CastSelf") -> "_1577.SquareMatrix":
        from mastapy._private.math_utility import _1577

        return self.__parent__._cast(_1577.SquareMatrix)

    @property
    def vector_6d(self: "CastSelf") -> "_1582.Vector6D":
        from mastapy._private.math_utility import _1582

        return self.__parent__._cast(_1582.Vector6D)

    @property
    def generic_matrix(self: "CastSelf") -> "GenericMatrix":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class GenericMatrix(_0.APIBase, Generic[TElement, TMatrix]):
    """GenericMatrix

    This is a mastapy class.

    Generic Types:
        TElement
        TMatrix
    """

    TYPE: ClassVar["Type"] = _GENERIC_MATRIX

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def number_of_columns(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfColumns

        if temp is None:
            return 0

        return temp

    @property
    def number_of_entries(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfEntries

        if temp is None:
            return 0

        return temp

    @property
    def number_of_rows(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfRows

        if temp is None:
            return 0

        return temp

    @property
    def data(self: "Self") -> "List[TElement]":
        """List[TElement]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Data

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @enforce_parameter_types
    def get_column_at(self: "Self", index: "int") -> "List[TElement]":
        """List[TElement]

        Args:
            index (int)
        """
        index = int(index)
        return conversion.pn_to_mp_objects_in_list(
            self.wrapped.GetColumnAt(index if index else 0)
        )

    @enforce_parameter_types
    def get_row_at(self: "Self", row_index: "int") -> "List[TElement]":
        """List[TElement]

        Args:
            row_index (int)
        """
        row_index = int(row_index)
        return conversion.pn_to_mp_objects_in_list(
            self.wrapped.GetRowAt(row_index if row_index else 0)
        )

    @property
    def cast_to(self: "Self") -> "_Cast_GenericMatrix":
        """Cast to another type.

        Returns:
            _Cast_GenericMatrix
        """
        return _Cast_GenericMatrix(self)



"""LeadFormReliefWithDeviation"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1149
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import
from mastapy._private._internal import utility

_LEAD_FORM_RELIEF_WITH_DEVIATION = python_net_import(
    "SMT.MastaAPI.Gears.GearDesigns.Cylindrical.MicroGeometry",
    "LeadFormReliefWithDeviation",
)

if TYPE_CHECKING:
    from typing import Any, Type, TypeVar

    from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1165

    Self = TypeVar("Self", bound="LeadFormReliefWithDeviation")
    CastSelf = TypeVar(
        "CastSelf",
        bound="LeadFormReliefWithDeviation._Cast_LeadFormReliefWithDeviation",
    )


__docformat__ = "restructuredtext en"
__all__ = ("LeadFormReliefWithDeviation",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_LeadFormReliefWithDeviation:
    """Special nested class for casting LeadFormReliefWithDeviation to subclasses."""

    __parent__: "LeadFormReliefWithDeviation"

    @property
    def lead_relief_with_deviation(self: "CastSelf") -> "_1149.LeadReliefWithDeviation":
        return self.__parent__._cast(_1149.LeadReliefWithDeviation)

    @property
    def relief_with_deviation(self: "CastSelf") -> "_1165.ReliefWithDeviation":
        from mastapy._private.gears.gear_designs.cylindrical.micro_geometry import _1165

        return self.__parent__._cast(_1165.ReliefWithDeviation)

    @property
    def lead_form_relief_with_deviation(
        self: "CastSelf",
    ) -> "LeadFormReliefWithDeviation":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class LeadFormReliefWithDeviation(_1149.LeadReliefWithDeviation):
    """LeadFormReliefWithDeviation

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _LEAD_FORM_RELIEF_WITH_DEVIATION

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cast_to(self: "Self") -> "_Cast_LeadFormReliefWithDeviation":
        """Cast to another type.

        Returns:
            _Cast_LeadFormReliefWithDeviation
        """
        return _Cast_LeadFormReliefWithDeviation(self)



"""ElectricMachineDetail"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import overridable, list_with_selected_item
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private.electric_machines import _1308
from mastapy._private._internal.python_net import python_net_import
from mastapy._private import _0
from mastapy._private._internal.cast_exception import CastException

_DATABASE_WITH_SELECTED_ITEM = python_net_import(
    "SMT.MastaAPI.UtilityGUI.Databases", "DatabaseWithSelectedItem"
)
_ELECTRIC_MACHINE_DETAIL = python_net_import(
    "SMT.MastaAPI.ElectricMachines", "ElectricMachineDetail"
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, List, TypeVar

    from mastapy._private.electric_machines import (
        _1297,
        _1309,
        _1338,
        _1282,
        _1285,
        _1320,
        _1331,
        _1334,
        _1348,
        _1350,
        _1365,
    )
    from mastapy._private.electric_machines.results import _1388, _1389
    from mastapy._private.math_utility import _1568
    from mastapy._private.utility import _1638
    from mastapy._private import _7724

    Self = TypeVar("Self", bound="ElectricMachineDetail")
    CastSelf = TypeVar(
        "CastSelf", bound="ElectricMachineDetail._Cast_ElectricMachineDetail"
    )


__docformat__ = "restructuredtext en"
__all__ = ("ElectricMachineDetail",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ElectricMachineDetail:
    """Special nested class for casting ElectricMachineDetail to subclasses."""

    __parent__: "ElectricMachineDetail"

    @property
    def cad_electric_machine_detail(
        self: "CastSelf",
    ) -> "_1285.CADElectricMachineDetail":
        from mastapy._private.electric_machines import _1285

        return self.__parent__._cast(_1285.CADElectricMachineDetail)

    @property
    def interior_permanent_magnet_machine(
        self: "CastSelf",
    ) -> "_1320.InteriorPermanentMagnetMachine":
        from mastapy._private.electric_machines import _1320

        return self.__parent__._cast(_1320.InteriorPermanentMagnetMachine)

    @property
    def non_cad_electric_machine_detail(
        self: "CastSelf",
    ) -> "_1331.NonCADElectricMachineDetail":
        from mastapy._private.electric_machines import _1331

        return self.__parent__._cast(_1331.NonCADElectricMachineDetail)

    @property
    def permanent_magnet_assisted_synchronous_reluctance_machine(
        self: "CastSelf",
    ) -> "_1334.PermanentMagnetAssistedSynchronousReluctanceMachine":
        from mastapy._private.electric_machines import _1334

        return self.__parent__._cast(
            _1334.PermanentMagnetAssistedSynchronousReluctanceMachine
        )

    @property
    def surface_permanent_magnet_machine(
        self: "CastSelf",
    ) -> "_1348.SurfacePermanentMagnetMachine":
        from mastapy._private.electric_machines import _1348

        return self.__parent__._cast(_1348.SurfacePermanentMagnetMachine)

    @property
    def synchronous_reluctance_machine(
        self: "CastSelf",
    ) -> "_1350.SynchronousReluctanceMachine":
        from mastapy._private.electric_machines import _1350

        return self.__parent__._cast(_1350.SynchronousReluctanceMachine)

    @property
    def wound_field_synchronous_machine(
        self: "CastSelf",
    ) -> "_1365.WoundFieldSynchronousMachine":
        from mastapy._private.electric_machines import _1365

        return self.__parent__._cast(_1365.WoundFieldSynchronousMachine)

    @property
    def electric_machine_detail(self: "CastSelf") -> "ElectricMachineDetail":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ElectricMachineDetail(_0.APIBase):
    """ElectricMachineDetail

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _ELECTRIC_MACHINE_DETAIL

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def core_loss_build_factor_specification_method(
        self: "Self",
    ) -> "_1297.CoreLossBuildFactorSpecificationMethod":
        """mastapy._private.electric_machines.CoreLossBuildFactorSpecificationMethod"""
        temp = self.wrapped.CoreLossBuildFactorSpecificationMethod

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.ElectricMachines.CoreLossBuildFactorSpecificationMethod"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.electric_machines._1297",
            "CoreLossBuildFactorSpecificationMethod",
        )(value)

    @core_loss_build_factor_specification_method.setter
    @enforce_parameter_types
    def core_loss_build_factor_specification_method(
        self: "Self", value: "_1297.CoreLossBuildFactorSpecificationMethod"
    ) -> None:
        value = conversion.mp_to_pn_enum(
            value,
            "SMT.MastaAPI.ElectricMachines.CoreLossBuildFactorSpecificationMethod",
        )
        self.wrapped.CoreLossBuildFactorSpecificationMethod = value

    @property
    def dc_bus_voltage(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.DCBusVoltage

        if temp is None:
            return 0.0

        return temp

    @dc_bus_voltage.setter
    @enforce_parameter_types
    def dc_bus_voltage(self: "Self", value: "float") -> None:
        self.wrapped.DCBusVoltage = float(value) if value is not None else 0.0

    @property
    def eddy_current_core_loss_build_factor(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.EddyCurrentCoreLossBuildFactor

        if temp is None:
            return 0.0

        return temp

    @eddy_current_core_loss_build_factor.setter
    @enforce_parameter_types
    def eddy_current_core_loss_build_factor(self: "Self", value: "float") -> None:
        self.wrapped.EddyCurrentCoreLossBuildFactor = (
            float(value) if value is not None else 0.0
        )

    @property
    def effective_machine_length(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EffectiveMachineLength

        if temp is None:
            return 0.0

        return temp

    @property
    def electric_machine_type(self: "Self") -> "_1309.ElectricMachineType":
        """mastapy._private.electric_machines.ElectricMachineType

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ElectricMachineType

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.ElectricMachines.ElectricMachineType"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.electric_machines._1309", "ElectricMachineType"
        )(value)

    @property
    def enclosing_volume(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.EnclosingVolume

        if temp is None:
            return 0.0

        return temp

    @property
    def excess_core_loss_build_factor(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ExcessCoreLossBuildFactor

        if temp is None:
            return 0.0

        return temp

    @excess_core_loss_build_factor.setter
    @enforce_parameter_types
    def excess_core_loss_build_factor(self: "Self", value: "float") -> None:
        self.wrapped.ExcessCoreLossBuildFactor = (
            float(value) if value is not None else 0.0
        )

    @property
    def has_non_linear_dq_model(self: "Self") -> "bool":
        """bool

        Note:
            This property is readonly.
        """
        temp = self.wrapped.HasNonLinearDQModel

        if temp is None:
            return False

        return temp

    @property
    def hysteresis_core_loss_build_factor(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.HysteresisCoreLossBuildFactor

        if temp is None:
            return 0.0

        return temp

    @hysteresis_core_loss_build_factor.setter
    @enforce_parameter_types
    def hysteresis_core_loss_build_factor(self: "Self", value: "float") -> None:
        self.wrapped.HysteresisCoreLossBuildFactor = (
            float(value) if value is not None else 0.0
        )

    @property
    def include_default_results_locations(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.IncludeDefaultResultsLocations

        if temp is None:
            return False

        return temp

    @include_default_results_locations.setter
    @enforce_parameter_types
    def include_default_results_locations(self: "Self", value: "bool") -> None:
        self.wrapped.IncludeDefaultResultsLocations = (
            bool(value) if value is not None else False
        )

    @property
    def include_shaft(self: "Self") -> "bool":
        """bool"""
        temp = self.wrapped.IncludeShaft

        if temp is None:
            return False

        return temp

    @include_shaft.setter
    @enforce_parameter_types
    def include_shaft(self: "Self", value: "bool") -> None:
        self.wrapped.IncludeShaft = bool(value) if value is not None else False

    @property
    def line_line_supply_voltage_rms(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.LineLineSupplyVoltageRMS

        if temp is None:
            return 0.0

        return temp

    @property
    def machine_periodicity_factor(self: "Self") -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = self.wrapped.MachinePeriodicityFactor

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @machine_periodicity_factor.setter
    @enforce_parameter_types
    def machine_periodicity_factor(
        self: "Self", value: "Union[int, Tuple[int, bool]]"
    ) -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        self.wrapped.MachinePeriodicityFactor = value

    @property
    def magnet_loss_build_factor(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.MagnetLossBuildFactor

        if temp is None:
            return 0.0

        return temp

    @magnet_loss_build_factor.setter
    @enforce_parameter_types
    def magnet_loss_build_factor(self: "Self", value: "float") -> None:
        self.wrapped.MagnetLossBuildFactor = float(value) if value is not None else 0.0

    @property
    def name(self: "Self") -> "str":
        """str"""
        temp = self.wrapped.Name

        if temp is None:
            return ""

        return temp

    @name.setter
    @enforce_parameter_types
    def name(self: "Self", value: "str") -> None:
        self.wrapped.Name = str(value) if value is not None else ""

    @property
    def number_of_phases(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfPhases

        if temp is None:
            return 0

        return temp

    @property
    def number_of_slots_per_phase(self: "Self") -> "int":
        """int

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfSlotsPerPhase

        if temp is None:
            return 0

        return temp

    @property
    def number_of_slots_per_pole(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfSlotsPerPole

        if temp is None:
            return 0.0

        return temp

    @property
    def number_of_slots_per_pole_per_phase(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NumberOfSlotsPerPolePerPhase

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_supply_voltage_peak(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PhaseSupplyVoltagePeak

        if temp is None:
            return 0.0

        return temp

    @property
    def phase_supply_voltage_rms(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.PhaseSupplyVoltageRMS

        if temp is None:
            return 0.0

        return temp

    @property
    def radial_air_gap(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RadialAirGap

        if temp is None:
            return 0.0

        return temp

    @radial_air_gap.setter
    @enforce_parameter_types
    def radial_air_gap(self: "Self", value: "float") -> None:
        self.wrapped.RadialAirGap = float(value) if value is not None else 0.0

    @property
    def rated_inverter_current_peak(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RatedInverterCurrentPeak

        if temp is None:
            return 0.0

        return temp

    @rated_inverter_current_peak.setter
    @enforce_parameter_types
    def rated_inverter_current_peak(self: "Self", value: "float") -> None:
        self.wrapped.RatedInverterCurrentPeak = (
            float(value) if value is not None else 0.0
        )

    @property
    def rated_inverter_phase_current_peak(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RatedInverterPhaseCurrentPeak

        if temp is None:
            return 0.0

        return temp

    @property
    def rotor_core_loss_build_factor(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.RotorCoreLossBuildFactor

        if temp is None:
            return 0.0

        return temp

    @rotor_core_loss_build_factor.setter
    @enforce_parameter_types
    def rotor_core_loss_build_factor(self: "Self", value: "float") -> None:
        self.wrapped.RotorCoreLossBuildFactor = (
            float(value) if value is not None else 0.0
        )

    @property
    def select_setup(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_ElectricMachineSetup":
        """ListWithSelectedItem[mastapy._private.electric_machines.ElectricMachineSetup]"""
        temp = self.wrapped.SelectSetup

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_ElectricMachineSetup",
        )(temp)

    @select_setup.setter
    @enforce_parameter_types
    def select_setup(self: "Self", value: "_1308.ElectricMachineSetup") -> None:
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_ElectricMachineSetup.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_ElectricMachineSetup.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.SelectSetup = value

    @property
    def shaft_diameter(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.ShaftDiameter

        if temp is None:
            return 0.0

        return temp

    @shaft_diameter.setter
    @enforce_parameter_types
    def shaft_diameter(self: "Self", value: "float") -> None:
        self.wrapped.ShaftDiameter = float(value) if value is not None else 0.0

    @property
    def shaft_material_database(self: "Self") -> "str":
        """str"""
        temp = self.wrapped.ShaftMaterialDatabase.SelectedItemName

        if temp is None:
            return ""

        return temp

    @shaft_material_database.setter
    @enforce_parameter_types
    def shaft_material_database(self: "Self", value: "str") -> None:
        self.wrapped.ShaftMaterialDatabase.SetSelectedItem(
            str(value) if value is not None else ""
        )

    @property
    def stator_core_loss_build_factor(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.StatorCoreLossBuildFactor

        if temp is None:
            return 0.0

        return temp

    @stator_core_loss_build_factor.setter
    @enforce_parameter_types
    def stator_core_loss_build_factor(self: "Self", value: "float") -> None:
        self.wrapped.StatorCoreLossBuildFactor = (
            float(value) if value is not None else 0.0
        )

    @property
    def non_linear_dq_model(self: "Self") -> "_1388.NonLinearDQModel":
        """mastapy._private.electric_machines.results.NonLinearDQModel

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NonLinearDQModel

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def non_linear_dq_model_generator_settings(
        self: "Self",
    ) -> "_1389.NonLinearDQModelGeneratorSettings":
        """mastapy._private.electric_machines.results.NonLinearDQModelGeneratorSettings

        Note:
            This property is readonly.
        """
        temp = self.wrapped.NonLinearDQModelGeneratorSettings

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def rotor(self: "Self") -> "_1338.Rotor":
        """mastapy._private.electric_machines.Rotor

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Rotor

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def selected_setup(self: "Self") -> "_1308.ElectricMachineSetup":
        """mastapy._private.electric_machines.ElectricMachineSetup

        Note:
            This property is readonly.
        """
        temp = self.wrapped.SelectedSetup

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def stator(self: "Self") -> "_1282.AbstractStator":
        """mastapy._private.electric_machines.AbstractStator

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Stator

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def results_locations(self: "Self") -> "List[_1568.Named2DLocation]":
        """List[mastapy._private.math_utility.Named2DLocation]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ResultsLocations

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def setups(self: "Self") -> "List[_1308.ElectricMachineSetup]":
        """List[mastapy._private.electric_machines.ElectricMachineSetup]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Setups

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def report_names(self: "Self") -> "List[str]":
        """List[str]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ReportNames

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp, str)

        if value is None:
            return None

        return value

    def generate_cad_geometry_model(self: "Self") -> None:
        """Method does not return."""
        self.wrapped.GenerateCADGeometryModel()

    @enforce_parameter_types
    def add_results_location(self: "Self", name: "str") -> None:
        """Method does not return.

        Args:
            name (str)
        """
        name = str(name)
        self.wrapped.AddResultsLocation(name if name else "")

    def add_setup(self: "Self") -> "_1308.ElectricMachineSetup":
        """mastapy._private.electric_machines.ElectricMachineSetup"""
        method_result = self.wrapped.AddSetup()
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def duplicate_setup(
        self: "Self", setup: "_1308.ElectricMachineSetup"
    ) -> "_1308.ElectricMachineSetup":
        """mastapy._private.electric_machines.ElectricMachineSetup

        Args:
            setup (mastapy._private.electric_machines.ElectricMachineSetup)
        """
        method_result = self.wrapped.DuplicateSetup(setup.wrapped if setup else None)
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def export_to_smt_format(self: "Self", file_name: "str") -> None:
        """Method does not return.

        Args:
            file_name (str)
        """
        file_name = str(file_name)
        self.wrapped.ExportToSMTFormat(file_name if file_name else "")

    def generate_design_without_non_linear_dq_model(
        self: "Self",
    ) -> "_1638.MethodOutcomeWithResult[ElectricMachineDetail]":
        """mastapy._private.utility.MethodOutcomeWithResult[mastapy._private.electric_machines.ElectricMachineDetail]"""
        method_result = self.wrapped.GenerateDesignWithoutNonLinearDQModel()
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def remove_results_location(self: "Self", name: "str") -> None:
        """Method does not return.

        Args:
            name (str)
        """
        name = str(name)
        self.wrapped.RemoveResultsLocation(name if name else "")

    @enforce_parameter_types
    def remove_setup(self: "Self", setup: "_1308.ElectricMachineSetup") -> None:
        """Method does not return.

        Args:
            setup (mastapy._private.electric_machines.ElectricMachineSetup)
        """
        self.wrapped.RemoveSetup(setup.wrapped if setup else None)

    @enforce_parameter_types
    def setup_named(self: "Self", name: "str") -> "_1308.ElectricMachineSetup":
        """mastapy._private.electric_machines.ElectricMachineSetup

        Args:
            name (str)
        """
        name = str(name)
        method_result = self.wrapped.SetupNamed(name if name else "")
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    def try_generate_non_linear_dq_model(
        self: "Self",
    ) -> "_1638.MethodOutcomeWithResult[ElectricMachineDetail]":
        """mastapy._private.utility.MethodOutcomeWithResult[mastapy._private.electric_machines.ElectricMachineDetail]"""
        method_result = self.wrapped.TryGenerateNonLinearDQModel()
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def try_generate_non_linear_dq_model_with_task_progress(
        self: "Self", progress: "_7724.TaskProgress"
    ) -> "_1638.MethodOutcomeWithResult[ElectricMachineDetail]":
        """mastapy._private.utility.MethodOutcomeWithResult[mastapy._private.electric_machines.ElectricMachineDetail]

        Args:
            progress (mastapy._private.TaskProgress)
        """
        method_result = self.wrapped.TryGenerateNonLinearDQModelWithTaskProgress(
            progress.wrapped if progress else None
        )
        type_ = method_result.GetType()
        return (
            constructor.new(type_.Namespace, type_.Name)(method_result)
            if method_result is not None
            else None
        )

    @enforce_parameter_types
    def write_dxf_to(self: "Self", file_name: "str") -> None:
        """Method does not return.

        Args:
            file_name (str)
        """
        file_name = str(file_name)
        self.wrapped.WriteDxfTo(file_name if file_name else "")

    @enforce_parameter_types
    def output_default_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputDefaultReportTo(file_path if file_path else "")

    def get_default_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetDefaultReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_active_report_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportTo(file_path if file_path else "")

    @enforce_parameter_types
    def output_active_report_as_text_to(self: "Self", file_path: "str") -> None:
        """Method does not return.

        Args:
            file_path (str)
        """
        file_path = str(file_path)
        self.wrapped.OutputActiveReportAsTextTo(file_path if file_path else "")

    def get_active_report_with_encoded_images(self: "Self") -> "str":
        """str"""
        method_result = self.wrapped.GetActiveReportWithEncodedImages()
        return method_result

    @enforce_parameter_types
    def output_named_report_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_masta_report(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsMastaReport(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def output_named_report_as_text_to(
        self: "Self", report_name: "str", file_path: "str"
    ) -> None:
        """Method does not return.

        Args:
            report_name (str)
            file_path (str)
        """
        report_name = str(report_name)
        file_path = str(file_path)
        self.wrapped.OutputNamedReportAsTextTo(
            report_name if report_name else "", file_path if file_path else ""
        )

    @enforce_parameter_types
    def get_named_report_with_encoded_images(self: "Self", report_name: "str") -> "str":
        """str

        Args:
            report_name (str)
        """
        report_name = str(report_name)
        method_result = self.wrapped.GetNamedReportWithEncodedImages(
            report_name if report_name else ""
        )
        return method_result

    @property
    def cast_to(self: "Self") -> "_Cast_ElectricMachineDetail":
        """Cast to another type.

        Returns:
            _Cast_ElectricMachineDetail
        """
        return _Cast_ElectricMachineDetail(self)



"""CylindricalGearFromCAD"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal.type_enforcement import enforce_parameter_types
from mastapy._private._internal.sentinels import ListWithSelectedItem_None
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private._internal.implicit import list_with_selected_item, overridable
from mastapy._private.system_model.part_model.gears import _2582, _2581
from mastapy._private._internal.overridable_constructor import _unpack_overridable
from mastapy._private.system_model.part_model.import_from_cad import _2560
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CYLINDRICAL_GEAR_FROM_CAD = python_net_import(
    "SMT.MastaAPI.SystemModel.PartModel.ImportFromCAD", "CylindricalGearFromCAD"
)

if TYPE_CHECKING:
    from typing import Any, Type, Union, Tuple, TypeVar

    from mastapy._private.geometry.two_d import _322
    from mastapy._private.system_model.part_model.import_from_cad import (
        _2555,
        _2556,
        _2557,
        _2558,
        _2551,
    )

    Self = TypeVar("Self", bound="CylindricalGearFromCAD")
    CastSelf = TypeVar(
        "CastSelf", bound="CylindricalGearFromCAD._Cast_CylindricalGearFromCAD"
    )


__docformat__ = "restructuredtext en"
__all__ = ("CylindricalGearFromCAD",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_CylindricalGearFromCAD:
    """Special nested class for casting CylindricalGearFromCAD to subclasses."""

    __parent__: "CylindricalGearFromCAD"

    @property
    def mountable_component_from_cad(
        self: "CastSelf",
    ) -> "_2560.MountableComponentFromCAD":
        return self.__parent__._cast(_2560.MountableComponentFromCAD)

    @property
    def component_from_cad(self: "CastSelf") -> "_2551.ComponentFromCAD":
        from mastapy._private.system_model.part_model.import_from_cad import _2551

        return self.__parent__._cast(_2551.ComponentFromCAD)

    @property
    def cylindrical_gear_in_planetary_set_from_cad(
        self: "CastSelf",
    ) -> "_2555.CylindricalGearInPlanetarySetFromCAD":
        from mastapy._private.system_model.part_model.import_from_cad import _2555

        return self.__parent__._cast(_2555.CylindricalGearInPlanetarySetFromCAD)

    @property
    def cylindrical_planet_gear_from_cad(
        self: "CastSelf",
    ) -> "_2556.CylindricalPlanetGearFromCAD":
        from mastapy._private.system_model.part_model.import_from_cad import _2556

        return self.__parent__._cast(_2556.CylindricalPlanetGearFromCAD)

    @property
    def cylindrical_ring_gear_from_cad(
        self: "CastSelf",
    ) -> "_2557.CylindricalRingGearFromCAD":
        from mastapy._private.system_model.part_model.import_from_cad import _2557

        return self.__parent__._cast(_2557.CylindricalRingGearFromCAD)

    @property
    def cylindrical_sun_gear_from_cad(
        self: "CastSelf",
    ) -> "_2558.CylindricalSunGearFromCAD":
        from mastapy._private.system_model.part_model.import_from_cad import _2558

        return self.__parent__._cast(_2558.CylindricalSunGearFromCAD)

    @property
    def cylindrical_gear_from_cad(self: "CastSelf") -> "CylindricalGearFromCAD":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class CylindricalGearFromCAD(_2560.MountableComponentFromCAD):
    """CylindricalGearFromCAD

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _CYLINDRICAL_GEAR_FROM_CAD

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def cad_drawing_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.CADDrawingDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def centre_distance(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.CentreDistance

        if temp is None:
            return 0.0

        return temp

    @centre_distance.setter
    @enforce_parameter_types
    def centre_distance(self: "Self", value: "float") -> None:
        self.wrapped.CentreDistance = float(value) if value is not None else 0.0

    @property
    def existing_gear_set(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_CylindricalGearSet":
        """ListWithSelectedItem[mastapy._private.system_model.part_model.gears.CylindricalGearSet]"""
        temp = self.wrapped.ExistingGearSet

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_CylindricalGearSet",
        )(temp)

    @existing_gear_set.setter
    @enforce_parameter_types
    def existing_gear_set(self: "Self", value: "_2582.CylindricalGearSet") -> None:
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_CylindricalGearSet.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_CylindricalGearSet.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.ExistingGearSet = value

    @property
    def face_width(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.FaceWidth

        if temp is None:
            return 0.0

        return temp

    @face_width.setter
    @enforce_parameter_types
    def face_width(self: "Self", value: "float") -> None:
        self.wrapped.FaceWidth = float(value) if value is not None else 0.0

    @property
    def gear_set_name(self: "Self") -> "str":
        """str"""
        temp = self.wrapped.GearSetName

        if temp is None:
            return ""

        return temp

    @gear_set_name.setter
    @enforce_parameter_types
    def gear_set_name(self: "Self", value: "str") -> None:
        self.wrapped.GearSetName = str(value) if value is not None else ""

    @property
    def helix_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.HelixAngle

        if temp is None:
            return 0.0

        return temp

    @helix_angle.setter
    @enforce_parameter_types
    def helix_angle(self: "Self", value: "float") -> None:
        self.wrapped.HelixAngle = float(value) if value is not None else 0.0

    @property
    def internal_external(self: "Self") -> "_322.InternalExternalType":
        """mastapy._private.geometry.two_d.InternalExternalType"""
        temp = self.wrapped.InternalExternal

        if temp is None:
            return None

        value = conversion.pn_to_mp_enum(
            temp, "SMT.MastaAPI.Geometry.TwoD.InternalExternalType"
        )

        if value is None:
            return None

        return constructor.new_from_mastapy(
            "mastapy._private.geometry.two_d._322", "InternalExternalType"
        )(value)

    @internal_external.setter
    @enforce_parameter_types
    def internal_external(self: "Self", value: "_322.InternalExternalType") -> None:
        value = conversion.mp_to_pn_enum(
            value, "SMT.MastaAPI.Geometry.TwoD.InternalExternalType"
        )
        self.wrapped.InternalExternal = value

    @property
    def meshing_gear(
        self: "Self",
    ) -> "list_with_selected_item.ListWithSelectedItem_CylindricalGear":
        """ListWithSelectedItem[mastapy._private.system_model.part_model.gears.CylindricalGear]"""
        temp = self.wrapped.MeshingGear

        if temp is None:
            return None

        selected_value = temp.SelectedValue

        if selected_value is None:
            return ListWithSelectedItem_None(temp)

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.list_with_selected_item",
            "ListWithSelectedItem_CylindricalGear",
        )(temp)

    @meshing_gear.setter
    @enforce_parameter_types
    def meshing_gear(self: "Self", value: "_2581.CylindricalGear") -> None:
        wrapper_type = (
            list_with_selected_item.ListWithSelectedItem_CylindricalGear.wrapper_type()
        )
        enclosed_type = (
            list_with_selected_item.ListWithSelectedItem_CylindricalGear.implicit_type()
        )
        value = wrapper_type[enclosed_type](
            value.wrapped if value is not None else None
        )
        self.wrapped.MeshingGear = value

    @property
    def normal_module(self: "Self") -> "overridable.Overridable_float":
        """Overridable[float]"""
        temp = self.wrapped.NormalModule

        if temp is None:
            return 0.0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_float"
        )(temp)

    @normal_module.setter
    @enforce_parameter_types
    def normal_module(self: "Self", value: "Union[float, Tuple[float, bool]]") -> None:
        wrapper_type = overridable.Overridable_float.wrapper_type()
        enclosed_type = overridable.Overridable_float.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0.0, is_overridden
        )
        self.wrapped.NormalModule = value

    @property
    def normal_pressure_angle(self: "Self") -> "float":
        """float"""
        temp = self.wrapped.NormalPressureAngle

        if temp is None:
            return 0.0

        return temp

    @normal_pressure_angle.setter
    @enforce_parameter_types
    def normal_pressure_angle(self: "Self", value: "float") -> None:
        self.wrapped.NormalPressureAngle = float(value) if value is not None else 0.0

    @property
    def number_of_teeth(self: "Self") -> "overridable.Overridable_int":
        """Overridable[int]"""
        temp = self.wrapped.NumberOfTeeth

        if temp is None:
            return 0

        return constructor.new_from_mastapy(
            "mastapy._private._internal.implicit.overridable", "Overridable_int"
        )(temp)

    @number_of_teeth.setter
    @enforce_parameter_types
    def number_of_teeth(self: "Self", value: "Union[int, Tuple[int, bool]]") -> None:
        wrapper_type = overridable.Overridable_int.wrapper_type()
        enclosed_type = overridable.Overridable_int.implicit_type()
        value, is_overridden = _unpack_overridable(value)
        value = wrapper_type[enclosed_type](
            enclosed_type(value) if value is not None else 0, is_overridden
        )
        self.wrapped.NumberOfTeeth = value

    @property
    def root_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.RootDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def tip_diameter(self: "Self") -> "float":
        """float

        Note:
            This property is readonly.
        """
        temp = self.wrapped.TipDiameter

        if temp is None:
            return 0.0

        return temp

    @property
    def cast_to(self: "Self") -> "_Cast_CylindricalGearFromCAD":
        """Cast to another type.

        Returns:
            _Cast_CylindricalGearFromCAD
        """
        return _Cast_CylindricalGearFromCAD(self)



"""ConicalGearMeshSteadyStateSynchronousResponseOnAShaft"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import constructor, conversion, utility
from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
    _3394,
)
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_CONICAL_GEAR_MESH_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.SteadyStateSynchronousResponsesOnAShaft",
    "ConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.system_model.connections_and_sockets.gears import _2360
    from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
        _3340,
        _3347,
        _3352,
        _3398,
        _3402,
        _3405,
        _3408,
        _3437,
        _3444,
        _3447,
        _3465,
        _3401,
        _3371,
    )
    from mastapy._private.system_model.analyses_and_results.analysis_cases import (
        _7706,
        _7703,
    )
    from mastapy._private.system_model.analyses_and_results import _2732, _2736, _2734

    Self = TypeVar(
        "Self", bound="ConicalGearMeshSteadyStateSynchronousResponseOnAShaft"
    )
    CastSelf = TypeVar(
        "CastSelf",
        bound="ConicalGearMeshSteadyStateSynchronousResponseOnAShaft._Cast_ConicalGearMeshSteadyStateSynchronousResponseOnAShaft",
    )


__docformat__ = "restructuredtext en"
__all__ = ("ConicalGearMeshSteadyStateSynchronousResponseOnAShaft",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_ConicalGearMeshSteadyStateSynchronousResponseOnAShaft:
    """Special nested class for casting ConicalGearMeshSteadyStateSynchronousResponseOnAShaft to subclasses."""

    __parent__: "ConicalGearMeshSteadyStateSynchronousResponseOnAShaft"

    @property
    def gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3394.GearMeshSteadyStateSynchronousResponseOnAShaft":
        return self.__parent__._cast(
            _3394.GearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def inter_mountable_component_connection_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> (
        "_3401.InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft"
    ):
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3401,
        )

        return self.__parent__._cast(
            _3401.InterMountableComponentConnectionSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def connection_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3371.ConnectionSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3371,
        )

        return self.__parent__._cast(
            _3371.ConnectionSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def connection_static_load_analysis_case(
        self: "CastSelf",
    ) -> "_7706.ConnectionStaticLoadAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7706,
        )

        return self.__parent__._cast(_7706.ConnectionStaticLoadAnalysisCase)

    @property
    def connection_analysis_case(self: "CastSelf") -> "_7703.ConnectionAnalysisCase":
        from mastapy._private.system_model.analyses_and_results.analysis_cases import (
            _7703,
        )

        return self.__parent__._cast(_7703.ConnectionAnalysisCase)

    @property
    def connection_analysis(self: "CastSelf") -> "_2732.ConnectionAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2732

        return self.__parent__._cast(_2732.ConnectionAnalysis)

    @property
    def design_entity_single_context_analysis(
        self: "CastSelf",
    ) -> "_2736.DesignEntitySingleContextAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2736

        return self.__parent__._cast(_2736.DesignEntitySingleContextAnalysis)

    @property
    def design_entity_analysis(self: "CastSelf") -> "_2734.DesignEntityAnalysis":
        from mastapy._private.system_model.analyses_and_results import _2734

        return self.__parent__._cast(_2734.DesignEntityAnalysis)

    @property
    def agma_gleason_conical_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3340.AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3340,
        )

        return self.__parent__._cast(
            _3340.AGMAGleasonConicalGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def bevel_differential_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3347.BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3347,
        )

        return self.__parent__._cast(
            _3347.BevelDifferentialGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def bevel_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3352.BevelGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3352,
        )

        return self.__parent__._cast(
            _3352.BevelGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def hypoid_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3398.HypoidGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3398,
        )

        return self.__parent__._cast(
            _3398.HypoidGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def klingelnberg_cyclo_palloid_conical_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3402.KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3402,
        )

        return self.__parent__._cast(
            _3402.KlingelnbergCycloPalloidConicalGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def klingelnberg_cyclo_palloid_hypoid_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3405.KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3405,
        )

        return self.__parent__._cast(
            _3405.KlingelnbergCycloPalloidHypoidGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def klingelnberg_cyclo_palloid_spiral_bevel_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3408.KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3408,
        )

        return self.__parent__._cast(
            _3408.KlingelnbergCycloPalloidSpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def spiral_bevel_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3437.SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3437,
        )

        return self.__parent__._cast(
            _3437.SpiralBevelGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def straight_bevel_diff_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3444.StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3444,
        )

        return self.__parent__._cast(
            _3444.StraightBevelDiffGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def straight_bevel_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3447.StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3447,
        )

        return self.__parent__._cast(
            _3447.StraightBevelGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def zerol_bevel_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "_3465.ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft":
        from mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft import (
            _3465,
        )

        return self.__parent__._cast(
            _3465.ZerolBevelGearMeshSteadyStateSynchronousResponseOnAShaft
        )

    @property
    def conical_gear_mesh_steady_state_synchronous_response_on_a_shaft(
        self: "CastSelf",
    ) -> "ConicalGearMeshSteadyStateSynchronousResponseOnAShaft":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class ConicalGearMeshSteadyStateSynchronousResponseOnAShaft(
    _3394.GearMeshSteadyStateSynchronousResponseOnAShaft
):
    """ConicalGearMeshSteadyStateSynchronousResponseOnAShaft

    This is a mastapy class.
    """

    TYPE: ClassVar[
        "Type"
    ] = _CONICAL_GEAR_MESH_STEADY_STATE_SYNCHRONOUS_RESPONSE_ON_A_SHAFT

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def connection_design(self: "Self") -> "_2360.ConicalGearMesh":
        """mastapy._private.system_model.connections_and_sockets.gears.ConicalGearMesh

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ConnectionDesign

        if temp is None:
            return None

        type_ = temp.GetType()
        return constructor.new(type_.Namespace, type_.Name)(temp)

    @property
    def planetaries(
        self: "Self",
    ) -> "List[ConicalGearMeshSteadyStateSynchronousResponseOnAShaft]":
        """List[mastapy._private.system_model.analyses_and_results.steady_state_synchronous_responses_on_a_shaft.ConicalGearMeshSteadyStateSynchronousResponseOnAShaft]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.Planetaries

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(
        self: "Self",
    ) -> "_Cast_ConicalGearMeshSteadyStateSynchronousResponseOnAShaft":
        """Cast to another type.

        Returns:
            _Cast_ConicalGearMeshSteadyStateSynchronousResponseOnAShaft
        """
        return _Cast_ConicalGearMeshSteadyStateSynchronousResponseOnAShaft(self)



"""RigidlyConnectedDesignEntityGroupModalAnalysis"""
from __future__ import annotations

from typing import TYPE_CHECKING, ClassVar

from mastapy._private._internal.dataclasses import extended_dataclass
from mastapy._private._internal import conversion, utility
from mastapy._private.system_model.analyses_and_results import _2735
from mastapy._private._internal.cast_exception import CastException
from mastapy._private._internal.python_net import python_net_import

_RIGIDLY_CONNECTED_DESIGN_ENTITY_GROUP_MODAL_ANALYSIS = python_net_import(
    "SMT.MastaAPI.SystemModel.AnalysesAndResults.ModalAnalyses.Reporting",
    "RigidlyConnectedDesignEntityGroupModalAnalysis",
)

if TYPE_CHECKING:
    from typing import Any, Type, List, TypeVar

    from mastapy._private.utility.modal_analysis import _1846

    Self = TypeVar("Self", bound="RigidlyConnectedDesignEntityGroupModalAnalysis")
    CastSelf = TypeVar(
        "CastSelf",
        bound="RigidlyConnectedDesignEntityGroupModalAnalysis._Cast_RigidlyConnectedDesignEntityGroupModalAnalysis",
    )


__docformat__ = "restructuredtext en"
__all__ = ("RigidlyConnectedDesignEntityGroupModalAnalysis",)


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class _Cast_RigidlyConnectedDesignEntityGroupModalAnalysis:
    """Special nested class for casting RigidlyConnectedDesignEntityGroupModalAnalysis to subclasses."""

    __parent__: "RigidlyConnectedDesignEntityGroupModalAnalysis"

    @property
    def design_entity_group_analysis(
        self: "CastSelf",
    ) -> "_2735.DesignEntityGroupAnalysis":
        return self.__parent__._cast(_2735.DesignEntityGroupAnalysis)

    @property
    def rigidly_connected_design_entity_group_modal_analysis(
        self: "CastSelf",
    ) -> "RigidlyConnectedDesignEntityGroupModalAnalysis":
        return self.__parent__

    def __getattr__(self: "CastSelf", name: str) -> "Any":
        try:
            return self.__getattribute__(name)
        except AttributeError:
            class_name = utility.camel(name)
            raise CastException(
                f'Detected an invalid cast. Cannot cast to type "{class_name}"'
            ) from None


@extended_dataclass(frozen=True, slots=True, weakref_slot=True)
class RigidlyConnectedDesignEntityGroupModalAnalysis(_2735.DesignEntityGroupAnalysis):
    """RigidlyConnectedDesignEntityGroupModalAnalysis

    This is a mastapy class.
    """

    TYPE: ClassVar["Type"] = _RIGIDLY_CONNECTED_DESIGN_ENTITY_GROUP_MODAL_ANALYSIS

    wrapped: "Any"

    def __post_init__(self: "Self") -> None:
        """Override of the post initialisation magic method."""
        if not hasattr(self.wrapped, "reference_count"):
            self.wrapped.reference_count = 0

        self.wrapped.reference_count += 1

    @property
    def excitation_frequencies_at_reference_speed(
        self: "Self",
    ) -> "List[_1846.DesignEntityExcitationDescription]":
        """List[mastapy._private.utility.modal_analysis.DesignEntityExcitationDescription]

        Note:
            This property is readonly.
        """
        temp = self.wrapped.ExcitationFrequenciesAtReferenceSpeed

        if temp is None:
            return None

        value = conversion.pn_to_mp_objects_in_list(temp)

        if value is None:
            return None

        return value

    @property
    def cast_to(self: "Self") -> "_Cast_RigidlyConnectedDesignEntityGroupModalAnalysis":
        """Cast to another type.

        Returns:
            _Cast_RigidlyConnectedDesignEntityGroupModalAnalysis
        """
        return _Cast_RigidlyConnectedDesignEntityGroupModalAnalysis(self)
